package edu.harvard.mgh.purcell.gplink.forms;

import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.TitledBorder;

import edu.harvard.mgh.purcell.gplink.base_form.*;
import edu.harvard.mgh.purcell.gplink.mainGUI.*;

/**
 * Creates a form that does a basic --assoc test
 * @author Kathe Todd-Brown
 *
 */
@SuppressWarnings("serial")
public class BasicFullAssocForm extends Forms {

	Forms.myCheckBox permButton, mpermButton,
		ciButton, adjustButton;
	//user input parameters
	myJTextField ciText, mpermText;
	
	static private Double CI_DEFAULT = new Double(0.95);
	static private Integer MPERM_DEFAULT = new Integer(1000);
	
	/**
	 * Create and show an allelic assocation test form.
	 * @param mf MainFrame that this form is aassociation with
	 */
	public BasicFullAssocForm(MainFrame mf) {
		super(mf, "Allelic Association Tests");
	}

	/**
	 * create the body specific to this form.
	 */
	@Override
	protected void createBody() {
		
		//toggle the mperm and perm options but also let the
		//...user select neither
		ActionListener toggle = new ActionListener(){
			public void actionPerformed(ActionEvent e){
				
				if(e.getSource().equals(mpermButton)
					&& mpermButton.isSelected())
					permButton.setSelected(false);
				if(e.getSource().equals(permButton)
					&& permButton.isSelected())
					mpermButton.setSelected(false);
			}
		};
		permButton.addActionListener(toggle);
		mpermButton.addActionListener(toggle);
		
		//set the layout for this body
		body.setLayout(new GridBagLayout());
		//declare and initalze the constraits for this layout
		GridBagConstraints c = new GridBagConstraints();
		//expand all the components in this layout to fill all
		//...avaliable horizontal space
		c.fill = GridBagConstraints.HORIZONTAL;	
		//resize the width to fill all availible space
		c.weightx = 1;
		//add a label to tell the user what form you are using
		body.add(new JLabel("Basic allelic single SNP " +
				"association [C/C or QT] (--assoc)"), c);
		//add the next component to the next level
		c.gridy = 1;
		//create a new panel for the --ci option to make
		//...the layout pretty
		JPanel ciPanel = new JPanel();
		ciPanel.setLayout(new BoxLayout(ciPanel, BoxLayout.X_AXIS));
		ciPanel.add(ciButton);
		ciPanel.add(ciText);
		//add the --ci <Double> to the form
		body.add(ciPanel, c);
		//move down
		c.gridy = 2;
		//add the --adjust option to the form
		body.add(adjustButton, c);
		//move down
		c.gridy = 3;
		//create a new panel to group the permulation options
		JPanel constraits = new JPanel();
		//tell the user what's in here
		constraits.setBorder(new TitledBorder("Permutation options "));
		//use a simple layout
		constraits.setLayout(new BoxLayout(constraits, BoxLayout.Y_AXIS));
		//add the --perm option
		constraits.add(permButton);
		//ya we could have used gridbag but desided to nest another jpanel
		//...if it bugs you change it
		JPanel mpPanel = new JPanel();
		//another simple layout
		mpPanel.setLayout(new BoxLayout(mpPanel, BoxLayout.X_AXIS));
		//make this panel left justified
		mpPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
		mpPanel.add(mpermButton);
		mpPanel.add(mpermText);
		constraits.add(mpPanel);
		//add the final componet
		body.add(constraits, c);
	}

	/**
	 * Pull the commandline from this form
	 */
	@Override
	protected String processBody() {
		String ans = "--assoc";
		if(ciButton.isSelected())
			ans +=" --ci " + ciText.getText();
		if(mpermButton.isSelected())
			ans += " --mperm " + mpermText.getText();
		if(permButton.isSelected())
			ans += " --perm";
		if(adjustButton.isSelected())
			ans += " --adjust";
		return ans;
	}

	/**
	 * Return true. --assoc is a vaild command by itself.
	 */
	@Override
	protected boolean isBodyValid() {
		if(ciButton.isSelected() && !ciText.getText().matches("\\d*\\.?\\d+")){
//			information.setText("--ci selected, you must specify a number");
			return false;
		}
		if(mpermButton.isSelected() && !mpermText.getText().matches("\\d*\\.?\\d+")){
//			information.setText("--mperm selected, you must specify a number");
			return false;
		}
		return true;
	}

	/**
	 * initalize all the variables.
	 */
	@Override
	protected void initalize() {
		body = new JPanel();
		ciText = new myJTextField(CI_DEFAULT.toString(), 4);
		mpermText = new myJTextField(MPERM_DEFAULT.toString(), 4);

		ciButton = new myCheckBox("Confidence interval, C/C only (--ci)", ciText);
		mpermButton = new myCheckBox("max(T) permutation mode (--mperm)", mpermText);
		permButton = new myCheckBox("Adaptive permutation mode (--perm)");
		adjustButton = new myCheckBox("Adjusted p-values (--adjust)");
	
	}
	
}
