package edu.harvard.mgh.purcell.gplink.mainGUI;

import java.awt.Font;
import java.awt.BorderLayout;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.border.TitledBorder;

/**
 * LogView displays the text of a file.
 * @author Kathe Todd-Brown
 *
 */
@SuppressWarnings("serial")
public class LogView extends JPanel {

	/**
	 * area for the actual text
	 */
	private JTextArea textout;
	/**
	 * label giving the name of the file we are looking at
	 */
	private JLabel file;
	/**
	 * the frame this is displayed in
	 */
	private MainFrame parent;
	
	/**
	 * Get the file we are currently looking at in the viewer.
	 * @return a string that gives the location of the file
	 */
	public String getCurrentFile(){
		return file.getText();
	}
	
	/**
	 * update repopulates the viewer with the text of a file. If 
	 * the file matches that already on display then don't re-read
	 * the text unless it is forced.
	 * @param fileName this string specifies file to read from
	 * @param force if this flag is true then it forces the display
	 * to update
	 */
	public void update(String fileName, boolean force){
		if(fileName.equals(file.getText()) && force == false
				&& (false == textout.getText().equals("")) )
			return;
		
		
		File reading = new File(fileName);
		
		if(reading.exists() == false){
			reading = new File(parent.data.getRoot(), fileName);
			
			if(reading.exists() == false)
				return;
		}
		
		textout.setText("");
		try {
			FileReader stdInput = new FileReader(reading);
			textout.read(stdInput, null);
			
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}catch (IOException e) {
			e.printStackTrace();
		}
		file.setText(reading.getAbsolutePath());
		
		
	}
	
	/**
	 * default constructor
	 * @param f the frame this is displayed in.
	 */
	public LogView(MainFrame f){
		super();
		parent = f;
		setLayout(new BorderLayout());
		setBorder(new TitledBorder("Log viewer"));
		
		file = new JLabel("No view selected");
		textout = new JTextArea(10,80);
		textout.setFont( new Font( "Monospaced", Font.PLAIN, 12 ));
		
		//this is only for viewing
		textout.setEditable(false);
		add(file, BorderLayout.PAGE_START);
		add(new JScrollPane(textout), BorderLayout.CENTER);
		
	}

}
