package edu.harvard.mgh.purcell.gplink.mainGUI;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.io.File;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JPanel;
import javax.swing.JSeparator;
import javax.swing.JTextField;

import edu.harvard.mgh.purcell.gplink.data.OpenSSHConnection;

/**
 * An extention of JDialog that get and sets the 
 * project folder information.
 * @author Kathe Todd-Brown
 *
 */
@SuppressWarnings("serial")
public class ProjectDialog extends JDialog {
	MainFrame frame;
	
	JTextField localFolder;
	JTextField remoteFolder;
	JButton browseRemote;
	JButton browseLocal;
	JCheckBox flagRemote;
	JPanel remotePanel;
	String hostname;
	String username;
	int portnum;
	
	JButton done;
	JButton cancel;
	
	/**
	 * launch a JFileChooser to set the local directory
	 */
	ActionListener getLocal = new ActionListener(){
		public void actionPerformed(ActionEvent arg0) {
//			 create a new dialog to pick the directory
			JFileChooser fc = new JFileChooser();
			// only look at directories
			fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
			// show the dialog and when it is OK-ed
			if (fc.showOpenDialog(ProjectDialog.this) == JFileChooser.APPROVE_OPTION) {
				localFolder.setText(fc.getSelectedFile().getAbsolutePath());
			}
			flagRemote.setEnabled(true);
		}
	};
	
	/**
	 * launch a RemoteFileChooser to set a remote directory
	 */
	ActionListener getRemote = new ActionListener(){

		public void actionPerformed(ActionEvent arg0) {
			new RemoteFileChooser(ProjectDialog.this, frame.data.getConn(), 
					remoteFolder, "~", true);			
		}
		
	};
	/**
	 * close everything up
	 */
	ActionListener cancelAction = new ActionListener(){
		public void actionPerformed(ActionEvent e) {
			frame.data.closeOldProject();
			frame.updateViews();
			dispose();
		}
	};
	
	/**
	 * 
	 */
	ActionListener setProject = new ActionListener(){
		@SuppressWarnings("static-access")
		public void actionPerformed(ActionEvent e) {

			if(! new File(localFolder.getText()).exists()){
				new ErrorDialog(frame, "You have selected a local project " +
						"folder that does not exist.\n Please create the folder and try again.");
				return;
			}
				
			
			if(flagRemote.isSelected() == true){
				frame.data.setLocalRoot(new File(localFolder.getText()));
				frame.data.setRemoteFile(remoteFolder.getText());
				
			}else
				frame.data.setRoot(new File(localFolder.getText()));
			
			
			
			if(! new File(frame.data.getRoot(), frame.data.LOG_FILE).exists())
				new ConfigDialog(frame);
			
			//if(frame.data.hasMetaLock() 
			//		&& frame.data.getReadOnly() == false){
			// set some menu to enabled since we now have a root folder
			frame.menuStuff.setMenuLock(frame.data.hasMetaLock());
			frame.menuStuff.options.setEnabled(true);
			//}
			frame.menuStuff.export.setEnabled(true);
			// update the operations panel
			frame.operationsView.updateView();
			
			dispose();
		}
	};
	
	public ProjectDialog(MainFrame mf, String local,
			String remote, String host, String user, int port){
		//this(mf, true);
		this(mf, false);
		//this.setVisible(false);
		localFolder.setText(local);
		flagRemote.setEnabled(true);
		remoteFolder.setText(remote);
				
		hostname = host;
		username = user;
		portnum = port;
		flagRemote.setSelected(true);
		
		pack();
		setVisible(true);
	}
	
	public ProjectDialog(MainFrame mf){
		this(mf, true);
	}
	
	public ProjectDialog(MainFrame mf, String local){
		this(mf, false);
		localFolder.setText(local);
		flagRemote.setEnabled(true);
		pack();
		setVisible(true);
	}
	
	public ProjectDialog(MainFrame mf, boolean visible){
		super(mf, "Set the project folder", true);
		frame = mf;
		
		frame.data.setRoot(null);
		
		
		hostname = "";
		username = "";
		portnum = 22;
		localFolder = new JTextField(30);
		localFolder.setEditable(false);
		remoteFolder = new JTextField(30);
		remoteFolder.setEditable(false);
		browseLocal = new JButton("Browse");
		browseRemote = new JButton("Browse");
		browseLocal.addActionListener(getLocal);
		browseRemote.addActionListener(getRemote);
		
		JPanel localPanel = new JPanel();
		localPanel.add(localFolder);
		localPanel.add(browseLocal);
		
		remotePanel = new JPanel();
		remotePanel.add(remoteFolder);
		remotePanel.add(browseRemote);
		remotePanel.setVisible(false);
		
		JButton close = new JButton("Cancel");
		close.addActionListener(cancelAction);
		
		flagRemote = new JCheckBox("Link to a remote project (via ssh to a Linux/Unix host)");
		flagRemote.addItemListener(new ItemListener(){
			public void itemStateChanged(ItemEvent arg0) {
				if(flagRemote.isSelected() == true){
					if(! new File(localFolder.getText()).exists())
						System.err.println("ProjectDialog: need a root folder set.");
					frame.data.setLocalRoot(new File(localFolder.getText()));
					OpenSSHConnection openConn;
					openConn = new OpenSSHConnection(frame.data, hostname, username, portnum);
					openConn.startGUI();
				} else {
					frame.data.closeRemote();
					frame.data.setLocalRoot(null);
				}
					
				ProjectDialog.this.remotePanel.setVisible(flagRemote.isSelected());
				//getRemote.setVisible(flagRemote.isSelected());
				pack();
			}
		});
		flagRemote.setEnabled(false);
		done = new JButton("Done");
		done.addActionListener(setProject);
		
		JPanel buttonPanel = new JPanel();
		done.setAlignmentY(Component.LEFT_ALIGNMENT);
		buttonPanel.add(done);
		
		close.setAlignmentY(Component.LEFT_ALIGNMENT);
		buttonPanel.add(close);
		
		this.getContentPane().setLayout(new BoxLayout( this.getContentPane(), BoxLayout.PAGE_AXIS));
		this.getContentPane().add(localPanel);
		this.getContentPane().add(flagRemote);
		this.getContentPane().add(new JSeparator());
		this.getContentPane().add(remotePanel);
		//this.getContentPane().add(getRemote);
		this.getContentPane().add(buttonPanel);
		
		pack();
		setVisible(visible);
	}
	
}
